==> mumble-1.2.2.tar.gz: mumble-1.2.2/src/mumble/licenses.h <==
static const char *licenseMumble = "Copyright (C) 2005-2010, Thorvald Natvig <thorvald@natvig.com>\n"
                                   "Copyright (C) 2007, Stefan Gehn <mETz AT gehn DOT net>\n"
                                   "Copyright (C) 2007, Sebastian Schlingmann <mit_service@users.sourceforge.net>\n"
                                   "Copyright (C) 2008-2009, Mikkel Krautz <mikkel@krautz.dk>\n"
                                   "Copyright (C) 2008, Andreas Messer <andi@bupfen.de>\n"
                                   "Copyright (C) 2007, Trenton Schulz\n"
                                   "Copyright (C) 2008-2009, Stefan Hacker <dd0t@users.sourceforge.net>\n"
                                   "\n"
                                   "All rights reserved.\n"
                                   "\n"
                                   "Redistribution and use in source and binary forms, with or without\n"
                                   "modification, are permitted provided that the following conditions\n"
                                   "are met:\n"
                                   "\n"
                                   "- Redistributions of source code must retain the above copyright notice,\n"
                                   "  this list of conditions and the following disclaimer.\n"
                                   "- Redistributions in binary form must reproduce the above copyright notice,\n"
                                   "  this list of conditions and the following disclaimer in the documentation\n"
                                   "  and/or other materials provided with the distribution.\n"
                                   "- Neither the name of the Mumble Developers nor the names of its\n"
                                   "  contributors may be used to endorse or promote products derived from this\n"
                                   "  software without specific prior written permission.\n"
                                   "\n"
                                   "THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS\n"
                                   "`AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT\n"
                                   "LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR\n"
                                   "A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR\n"
                                   "CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,\n"
                                   "EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,\n"
                                   "PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR\n"
                                   "PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF\n"
                                   "LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING\n"
                                   "NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS\n"
                                   "SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.";

==> mumble_1.2.3.orig.tar.gz: mumble-1.2.3/src/mumble/licenses.h <==
static const char *licenseMumble = "Copyright (C) 2005-2010, Thorvald Natvig <thorvald@natvig.com>\n"
                                   "Copyright (C) 2007, Stefan Gehn <mETz AT gehn DOT net>\n"
                                   "Copyright (C) 2007, Sebastian Schlingmann <mit_service@users.sourceforge.net>\n"
                                   "Copyright (C) 2008-2010, Mikkel Krautz <mikkel@krautz.dk>\n"
                                   "Copyright (C) 2008, Andreas Messer <andi@bupfen.de>\n"
                                   "Copyright (C) 2007, Trenton Schulz\n"
                                   "Copyright (C) 2008-2010, Stefan Hacker <dd0t@users.sourceforge.net>\n"
                                   "Copyright (C) 2008-2010, Snares <snares@users.sourceforge.net>\n"
                                   "Copyright (C) 2009-2010, Benjamin Jemlich <pcgod@users.sourceforge.net>\n"
                                   "\n"
                                   "All rights reserved.\n"
                                   "\n"
                                   "Redistribution and use in source and binary forms, with or without\n"
                                   "modification, are permitted provided that the following conditions\n"
                                   "are met:\n"
                                   "\n"
                                   "- Redistributions of source code must retain the above copyright notice,\n"
                                   "  this list of conditions and the following disclaimer.\n"
                                   "- Redistributions in binary form must reproduce the above copyright notice,\n"
                                   "  this list of conditions and the following disclaimer in the documentation\n"
                                   "  and/or other materials provided with the distribution.\n"
                                   "- Neither the name of the Mumble Developers nor the names of its\n"
                                   "  contributors may be used to endorse or promote products derived from this\n"
                                   "  software without specific prior written permission.\n"
                                   "\n"
                                   "THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS\n"
                                   "`AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT\n"
                                   "LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR\n"
                                   "A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR\n"
                                   "CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,\n"
                                   "EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,\n"
                                   "PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR\n"
                                   "PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF\n"
                                   "LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING\n"
                                   "NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS\n"
                                   "SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n";
